@@ -46,9 +46,6 @@
 
 #include "msd-keyboard-xkb.h"
 
-#define MSD_KEYBOARD_MANAGER_GET_PRIVATE(o) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((o), MSD_TYPE_KEYBOARD_MANAGER, MsdKeyboardManagerPrivate))
-
 #define MSD_KEYBOARD_SCHEMA "org.mate.peripherals-keyboard"
 
 #define KEY_REPEAT         "repeat"
@@ -70,11 +67,9 @@ struct MsdKeyboardManagerPrivate {
 	GSettings  *settings;
 };
 
-static void     msd_keyboard_manager_class_init  (MsdKeyboardManagerClass* klass);
-static void     msd_keyboard_manager_init        (MsdKeyboardManager*      keyboard_manager);
-static void     msd_keyboard_manager_finalize    (GObject*                 object);
+static void     msd_keyboard_manager_finalize    (GObject *object);
 
-G_DEFINE_TYPE (MsdKeyboardManager, msd_keyboard_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (MsdKeyboardManager, msd_keyboard_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
@@ -354,14 +349,12 @@ msd_keyboard_manager_class_init (MsdKeyboardManagerClass *klass)
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
         object_class->finalize = msd_keyboard_manager_finalize;
-
-        g_type_class_add_private (klass, sizeof (MsdKeyboardManagerPrivate));
 }
 
 static void
 msd_keyboard_manager_init (MsdKeyboardManager *manager)
 {
-        manager->priv = MSD_KEYBOARD_MANAGER_GET_PRIVATE (manager);
+        manager->priv = msd_keyboard_manager_get_instance_private (manager);
 }
 
 static void
