@@ -64,34 +64,63 @@ update_state (GtkWidget *window)
         case 4:
                 msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
                                                          "media-eject",
-                                                         FALSE);
+                                                         NULL);
 
                 gtk_widget_show (window);
                 break;
-        case 5:
-                msd_media_keys_window_set_volume_level (MSD_MEDIA_KEYS_WINDOW (window),
-                                                        0);
+	case 5:
                 msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
-                                                         "gpm-brightness-lcd",
-                                                         TRUE);
+                                                         "touchpad-disabled",
+                                                         _("Touchpad disabled"));
 
                 gtk_widget_show (window);
                 break;
         case 6:
-                msd_media_keys_window_set_volume_level (MSD_MEDIA_KEYS_WINDOW (window),
-                                                        50);
                 msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
-                                                         "gpm-brightness-lcd",
-                                                         TRUE);
+                                                         "input-touchpad",
+                                                         _("Touchpad enabled"));
 
                 gtk_widget_show (window);
                 break;
-        case 7:
-                msd_media_keys_window_set_volume_level (MSD_MEDIA_KEYS_WINDOW (window),
-                                                        100);
+	case 7:
                 msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
-                                                         "gpm-brightness-lcd",
-                                                         TRUE);
+                                                         "bluetooth-disabled-symbolic",
+                                                         _("Bluetooth disabled"));
+
+                gtk_widget_show (window);
+                break;
+        case 8:
+                msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
+                                                         "bluetooth-active-symbolic",
+                                                         _("Bluetooth enabled"));
+
+                gtk_widget_show (window);
+                break;
+        case 9:
+                msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
+                                                         "airplane-mode-symbolic",
+                                                         _("Airplane mode enabled"));
+
+                gtk_widget_show (window);
+                break;
+        case 10:
+                msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
+                                                         "network-wireless-signal-excellent-symbolic",
+                                                         _("Airplane mode disabled"));
+
+                gtk_widget_show (window);
+                break;
+        case 11:
+                msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
+                                                         "video-single-display-symbolic",
+                                                         _("No External Display"));
+
+                gtk_widget_show (window);
+                break;
+        case 12:
+                msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (window),
+                                                         "video-joined-displays-symbolic",
+                                                         _("Changing Screen Layout"));
 
                 gtk_widget_show (window);
                 break;
@@ -141,9 +170,6 @@ main (int    argc,
                 exit (1);
         }
 
-        gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           DATADIR G_DIR_SEPARATOR_S "mate-power-manager" G_DIR_SEPARATOR_S "icons");
-
         test_window ();
 
         gtk_main ();
